# by DCL manual
=begin
==NumRu::AdvancedDCL::Axis
=={W[ɂ
AxisW[͎Ŏ`߂̃W[łB
===W̏ꏊ
Axis, Axis::Lin, Axis::Log g߂ɂ, 炩ߕϊ֐ԍ 1`4 (pWn)̐Kϊݒ肳ĂȂ΂ȂȂ ( ((<{Ců{\>)) Q). Ƃ 
  Fig.viewport=[VXMIN,VXMAX,VYMIN,VYMAX]
  Fig.window=[UXMIN,UXMAX,UYMIN,UYMAX] 
  Fig.transnum=ITR
ĂłƂ. ̂Ƃ Axis::Lin ͎̏ꏊɍWݒł. 

XɂĂ 
  'B'ottom - (UXMIN, UYMIN) (UXMAX, UYMIN)Ԑ
  'T'op - (UXMIN, UYMAX) (UXMAX, UYMAX)Ԑ
  'U'ser - (UXMIN, UYUSER) (UXMAX, UYUSER)Ԑ

YɂĂ
  'L'eft - (UXMIN, UYMIN) (UXMIN, UYMAX)Ԑ
  'R'ight - (UXMAX, UYMIN) (UXMAX, UYMAX)Ԑ
  'U'ser - (UXUSER, UYMIN) (UXUSER, UYMAX)Ԑ

XɊւ'B', 'T', 'U', YɊւ'L', 'R', 'U', W̍\vf(ߎQ)悷ꏊ߂̃p[^[(CSIDE)Ƃėp. UXUSER, UYUSER̓p^ uxuser, uyuser ݒ肵ď߂ėLƂȂ(l͕s). Wݒł邱̏ꏊ, XɂĂ Axis::Lin.xsaxs ɂ Yɕsړ邱Ƃł; YɂĂ Axis::Lin.ysaxs ɂ Xɕsړ邱Ƃł. 

===W̍\vfƂ̑
Axis::Lin 悷W̍\vfɂ͎̂̂ (JbR͂̍\vf`Tu[`). 
  (1)  (Axis::Lin.xpaxs/ypaxs) 
  (2) ڐ (Axis::Lin.xptmk/yptmk) 
  (3) x 
      * Ŏw (Axis::Lin.xplbl/yplbl) 
      * lŎw (Axis::Lin.xpnum/ypnum) 
  (4) ^Cg (Axis::Lin.xpttl/ypttl) 

ꂼ̍\vf͎̂悤ȑĂ. 
  (1) ɂĂ 
        a. ̃CCfNX <ISLCT>
  (2) ڐɂĂ 
        a. ڐ̒ <ISLCT>
        b. ڐ`̃CCfNX <ISLCT>
  (3) xɂĂ 
        a. ̍ <ISLCT>
        b. ̉]p <CSIDE>
        c. ̃Z^OIvV <CSIDE>
        d. `̃CCfNX <ISLCT>
  (4) ^CgɂĂ 
        a. ̍ <ISLCT>
        b. ̉]p <CSIDE>
        c. ̃Z^OIvV <>
        d. `̃CCfNX <ISLCT>

̑̎w@ <ISLCT>, <CSIDE>, <> ӖɂĂ͎߂ŏqׂ. 

W̐ݒ'U'serȊOłȂꍇ, xƃ^Cg͏ɃEChE̊OɌĕ`. 'U'serŐݒȂꍇ, xƃ^Cĝǂ瑤ɏ ϐ'IFLAG'߂.

===̎w@
Axis::Lin ̊eTu[`ɂISLCT, CSIDEƂ2̈. 2̈т̑̈e\vf̑߂. 
(1) ISLCT0,1,2̒lƂ肤. 3.3߂ŏqׂ ̂<ISLCT>Ƃ̂,̈ɂĒ܂p^QƂČ܂.
    ISLCT=0,1,2̋̓IȈӖ, 
    * ISLCT=0 : [U[`ϐgč悷. 
    * ISLCT=1 : ̃pbP[W炩ߐݒ肵Ă ϐgč悷. ߂̖ڐ, x, ^Cg`Ƃɗp. 
    * ISLCT=2 : ̃pbP[W炩ߐݒ肵Ă ϐgč悷. 傫߂̖ڐ, x, ^Cg`Ƃɗp. 
             
Ƃ, ̃CCfNXɂĂ, ISLCT=0,1,2ꂼɂ indext0, indext1, indext2 Ƃp^(l͏, s, 1, 3) QƂđ܂. ȉł͈ȏ̕\܂Ƃ߂Ď̂悤ɗL. -- up^ index(i) Ŏw肵ĂlQƂăCCfNX̑܂(l, s, 1, 3)v. ̃p^ Axis::Lin.get, Axis::Lin.set ɂ Q/ύXł. 
(2) CSIDE͍\vf`ꏊw肷ƂƂ, `ꏊɈˑ鑮߂. O߂ŏqׂ̂<CSIDE>Ƃ̂, ̈ɂĒ܂p^QƂČ܂. Ƃ, Xɂ^Cg̉]pɂĂ, CSIDE='B','T','U'ꂼɂ irotcxb, irotcxt, irotcxu Ƃp^(l͏, 0, 0, 0) QƂđ܂. ȉł͈ȏ̕\܂Ƃ߂Ď̂悤ɗL. -- up^ irotcx(s) Ŏw肵ĂlQƂ, Xɂ^Cg̉]pɊւ鑮܂(l, 0, 0, 0)v. ܂, Yɂ^Cg̉]pɂĂ, CSIDE='L','R','U'ꂼɂ irotcyl, irotcyr, irotcyu Ƃp^(l͏, 1, 1, 1) QƂđ܂. ȉł͈ȏ̕\܂Ƃ߂Ď̂悤ɗL. -- up^ irotcy(s) Ŏw肵ĂlQƂ, Yɂ^Cg̉]pɊւ鑮܂(l, 1, 1, 1)v.  irotcx(s)  irotcy(s) ܂Ƃ߂Ď̂悤ɗL. -- up^ irotc(zs) Ŏw肵ĂlQƂ,ɂ郉x̉]pɊւ鑮܂(l, 0, 0, 0, 1, 1, 1)v. 
(3) O߂ŏqׂ̂<>Ƃ̂, ƂĒڎw肷邱ƂɂČ܂. 

O߂ŏqׂ͋̓IɎ̂悤Ɍ܂. 
(1) ɂĂ 
      a. ̃CCfNX <ISLCT> 
      p^ indext(i)Ŏw肵Ă郉CCfNXpĐ` (l, s, 1, 3). 
(2) ڐɂĂ 
      a. ڐ̒ <ISLCT> 
      p^ rsizet(i)Ŏw肵Ă钷(PʂVWn)̖ڐ` (l, s, 0.007, 0.014). 
      b. ڐ`̃CCfNX <ISLCT> 
      p^ indext(i)Ŏw肵Ă郉CCfNXpĖڐ` (l, s, 1, 3). (:ڐ`̓p^ inner ߂. inner ̂ƂɌĖڐ`; ̂ƂOɌĖڐ`(l+1). ) 
(3) xɂĂ 
      a. ̍ <ISLCT> 
      p^ rsizel(i) Ŏw肵Ă鍂(PʂVWn)̕` (l, s, 0.021, 0.028). 
      b. ̉]p <CSIDE> 
      p^ irotl(zs) Ŏw肵Ă]pIvVgăx`(l, 0, 0, 0, 0, 0, 0). ]pIvVƂ,x`Ƃ̉]p90x 1Pʂ̐lŎw肷̂ł. (Ƃ90x̂Ƃ1, -90x̂Ƃ-1Ǝw肷.) 
      c. ̃Z^OIvV <CSIDE> 
      p^ icent(zs) Ŏw肵ĂZ^OIvVgăx`(l, 0, 0, 0, +1, +1, +1). Z^OIvVƂ, x`Ƃɍ悹(-1)邩, Z^O(0)邩, E悹(+1)邩w肷̂ł. 
      d. `̃CCfNX <ISLCT> 
      p^ indexl(i) Ŏw肵Ă郉CCfNXpĕ` (l, s, 3, 3). 
(4) ^CgɂĂ 
      a. ̍ <ISLCT> 
      p^ rsizec(i) Ŏw肵Ă鍂(PʂVWn)̕` (l, s, 0.028, 0.035). 
      b. ̉]p <CSIDE> 
      p^ irotc(zs) Ŏw肵Ă]pIvVgăx`(l, 0, 0, 0, +1, +1, +1). ]pIvVƂ, ^Cg`Ƃ̉]p90x 1Pʂ̐lŎw肷̂ł. (Ƃ90x̂Ƃ1, -90x̂Ƃ-1Ǝw肷. ) 
      c. ̃Z^OIvV <> 
      Ŏw肵ĂZ^OIvV gă^Cg`. Z^OIvVƂ, x`Ƃɍ悹(-1)邩, Z^O(0)邩, E悹(+1)邩w肷̂ł. 
      d. `̃CCfNX <ISLCT> 
      p^ indexl(i) Ŏw肵Ă郉CCfNXpĕ` (l, s, 3, 3).
 
===p^
p^ p^̌^ ΉDCLpbP[W
:ireset(Fixnum)<USPACK>
   USINITŎIɃp[^ Zbg邱Ƃw肷ϐ. l1. 
    * 0: XP[Op^Ȃ ( * ̂ϐ) ̃ZbĝݍsȂ. 
    * 1: ireset=0 ɉă^Cg̃Zbg. 
    * 2: AxiŝׂẴp^ Zbg. 
   USINIT͒ʏ Frame.newĂ΂.
:lxinv(true or false)<USPACK>
   TRUE̎, X̍Etɂ.
:lyinv(true or false)<USPACK>
   TRUE̎, Y̏㉺tɂ.
:lmatch(true or false)<USPACK>
   TRUE̎, XỸxԊuy Ԋu𓯂ɂ.
:rmrgn(Float)<USPACK>
   }[W̕. Pʂ͕. (9.524)
:xfac*(Float)<USPACK>
   XW̃t@N^[l (999.)
:yfac*(Float)<USPACK>
   YW̃t@N^[l (999.)
:xoff*(Float)<USPACK>
   lXW̃ItZbgl (999.)
:yoff*(Float)<USPACK>
   lYW̃ItZbgl (999.)
:dxt*(Float)<USPACK>
   lXW̖ڐ̊Ԋu (999.)
:dyt*(Float)<USPACK>
   lYW̖ڐ̊Ԋu (999.)
:dxl*(Float)<USPACK>
   lXW̃x̊Ԋu (999.)
:dyl*(Float)<USPACK>
   lYW̃x̊Ԋu (999.)
:tfact(Float)<USPACK>
   lW̖ڐԊu̖ڈ (2).̒lɕ ( rsize1) | ȊԊu, ؂̂悢ldutƂĐݒ肷.
:mxdgtx(Fixnum)<USPACK>
   lXW̃x̍ő包 (4)
:mxdgty(Fixnum)<USPACK>
   lYW̃x̍ő包 (4).x̌̒l傫ȂƂ, uoff, ufac ݒ肵 ̌ȓɂ܂悤Ɏ݂.
:nblank1(Fixnum)<USPACK>
   xWƕsȏꍇ, xԂ̍ŏ󔒐. (lW) (1)
:nblank2(Fixnum)<USPACK>
   xWƒpȏꍇ, xԂ̍ŏ󔒐. (lW) (2)
:nlblx*(Fixnum)<USPACK>
   ΐXW̃x` (999)
:nlbly*(Fixnum)<USPACK>
   ΐYW̃x` (999)
:nticksx*(Fixnum)<USPACK>
   ΐXẄꌅ̊Ԃ̖ڐ̐ (999)
:nticksy*(Fixnum)<USPACK>
   ΐYẄꌅ̊Ԃ̖ڐ̐ (999)
:itypex*(Fixnum)<USPACK>
   ΐXW̃^Cv (999)
:itypey*(Fixnum)<USPACK>
   ΐYW̃^Cv (999)
:mxdgtsx(Fixnum)<USPACK>
   X̃Tux̏ꍇ, mxdgtsxŎw肳ꂽ̃x͈̔͂ zȂ悤ɃTux`.
:mxdgtsy(Fixnum)<USPACK>
   ỸTux̏ꍇ, mxdgtsyŎw肳ꂽ̃x͈̔͂ zȂ悤ɃTux`.
:lprtct(true or false)<USPACK>
   Tux𑼕̎̃ẍ ܂ŕ`ȂƂw肷. ꂪ TRUE̎ɂ mxdgtsx/mxdgtsy ̎w͖.
:soffxtr*, soffxtl*, soffxbr*, soffxbl*, soffxur*, soffxul*(Float)<USPACK>
   X̃Tux̃ItZbgl. 
:soffytr*, soffyrb*, soffylt*, soffylb*, soffyut*, soffyub*(Float)<USPACK>
   ỸTux̃ItZbgl. 
:xdtmax*, xdtmin*(Float)<USPACK>
   Fig.inclpoint Őݒ肳ꂽ x W̍őŏl.
:ydtmax*, ydtmin*(Float)<USPACK>
   Fig.inclpoint Őݒ肳ꂽ y W̍őŏl.
:cxttl(String)<USPACK>
   X̃^Cg (32ȓ)
:cyttl(String)<USPACK>
   Ỹ^Cg (32ȓ)
:cxfmt(String)<USPACK>
   X̃x̃tH[}bg (1)
:cyfmt(String)<USPACK>
   Ỹx̃tH[}bg (1)
:cxside(String)<USPACK>
   Xʒu. 'T'(Top), 'B'(Bottom), 'U'(User) ̂ 2܂Ŏwł. 2̈ʒûŏɎw肵ʒu Tuxƃ^Cg. (2)
:cyside(String)<USPACK>
   Y`ʒu. 'R'(Right), 'L'(Left), 'U'(User) ̂ 2܂Ŏwł. 2̈ʒûŏɎw肵ʒu Tuxƃ^Cg. (2)
:cxspos(String)<USPACK>
   X̃Tuxʒu 'R' ܂ 'L'
:cyspos(String)<USPACK>
   ỸTuxʒu 'T' ܂ 'B'
:cxunit(String)<USPACK>
   X̃TuxɏP (32ȓ)
:cyunit(String)<USPACK>
   ỸTuxɏP (32ȓ)
:cblkt(String)<USPACK>
   ỸTuxɏP (32ȓ)
:labelxb(true or false)<UZPACK>
   x`ǂw肷ϐ;TRUEȂ`, FALSEȂ`Ȃ(TRUE)
:labelxt(true or false)<UZPACK>
   x`ǂw肷ϐ;TRUEȂ`, FALSEȂ`Ȃ(FALSE)
:labelxu(true or false)<UZPACK>
   x`ǂw肷ϐ;TRUEȂ`, FALSEȂ`Ȃ(TRUE)
:labelyl(true or false)<UZPACK>
   x`ǂw肷ϐ;TRUEȂ`, FALSEȂ`Ȃ(TRUE)
:labelyr(true or false)<UZPACK>
   x`ǂw肷ϐ;TRUEȂ`, FALSEȂ`Ȃ(FALSE)
:labelyu(true or false)<UZPACK>
   x`ǂw肷ϐ;TRUEȂ`, FALSEȂ`Ȃ(TRUE)
:rsizet0(Float)<UZPACK>
   ڐ̒w肷ϐ(PʂVWn)(s)
:rsizet1(Float)<UZPACK>
   ڐ̒w肷ϐ(PʂVWn)(0.007)
:rsizet2(Float)<UZPACK>
   ڐ̒w肷ϐ(PʂVWn)(0.014)
:rsizel0(Float)<UZPACK>
   x̍̕w肷ϐ(PʂVWn)(s)
:rsizel1(Float)<UZPACK>
   x̍̕w肷ϐ(PʂVWn)(0.021)
:rsizel2(Float)<UZPACK>
   x̍̕w肷ϐ(PʂVWn)(0.028)
:rsizec0(Float)<UZPACK>
   ^Cg̍̕w肷ϐ(PʂVWn)(s)
:rsizec1(Float)<UZPACK>
   ^Cg̍̕w肷ϐ(PʂVWn)(0.028)
:rsizec2(Float)<UZPACK>
   ^Cg̍̕w肷ϐ(PʂVWn)(0.035)
:uxuser(Float)<UZPACK>
   Y̍惋[`ɂďꏊp[^[Ƃ'U'serw肵ƂɗpXWl(l͕s). 
:uyuser(Float)<UZPACK>
   X̍惋[`ɂďꏊp[^[Ƃ'U'serw肵ƂɗpYWl(l͕s). 

(1) ̃tH[}bgzɎw肵ꍇ, x̊ԊuȂǂɂ͔̏fȂ̂, dxl, dyl K؂Ɏw肵Ȃ,xdȂꍇ. 
(2)ϐ cxside, cyside Ŏw肳ŏ̈ʒu label(zs)FALSE̎ɂ, Tux, ^CgƂɕ`Ȃ. 

܂Ãp^̓\bhƂėp邱ƂłBȂ킿AAxis.iresetŃp^ireset̎QƂAAxis.ireset=Ńp^ireset̕ύXłB

=end

module NumRu
  module AdvancedDCL
    module Axis
      def param_init
	@param = Parameter.new(Common.param)
	
	@param.init("ireset", Fixnum, "usiset", "usiget", 0, 0)
	@param.init("lxinv", TrueClass, "uslset", "uslget", 0, 0)
	@param.init("lyinv", TrueClass, "uslset", "uslget", 0, 0)
	@param.init("lxsub", TrueClass, "uslset", "uslget", 0, 0)
	@param.init("lysub", TrueClass, "uslset", "uslget", 0, 0)
	@param.init("lmatch", TrueClass, "uslset", "uslget", 0, 0)
	@param.init("rmrgn", Float, "usrset", "usrget", 0, 0)
	@param.init("xfac", Float, "usrset", "usrget", 0, 0)
	@param.init("yfac", Float, "usrset", "usrget", 0, 0)
	@param.init("xoff", Float, "usrset", "usrget", 0, 0)
	@param.init("yoff", Float, "usrset", "usrget", 0, 0)
	@param.init("dxt", Float, "usrset", "usrget", 0, 0)
	@param.init("dyt", Float, "usrset", "usrget", 0, 0)
	@param.init("dxl", Float, "usrset", "usrget", 0, 0)
	@param.init("dyl", Float, "usrset", "usrget", 0, 0)
	@param.init("tfact", Float, "usrset", "usrget", 0, 0)
	@param.init("mxdgtx", Fixnum, "usiset", "usiget", 0, 0)
	@param.init("mxdgty", Fixnum, "usiset", "usiget", 0, 0)
	@param.init("nblank1", Fixnum, "usiset", "usiget", 0, 0)
	@param.init("nblank2", Fixnum, "usiset", "usiget", 0, 0)
	@param.init("nlblx", Fixnum, "usiset", "usiget", 0, 0)
	@param.init("nlbly", Fixnum, "usiset", "usiget", 0, 0)
	@param.init("nticksx", Fixnum, "usiset", "usiget", 0, 0)
	@param.init("nticksy", Fixnum, "usiset", "usiget", 0, 0)
	@param.init("itypex", Fixnum, "usiset", "usiget", 0, 0)
	@param.init("itypey", Fixnum, "usiset", "usiget", 0, 0)
	@param.init("mxdgtsx", Fixnum, "usiset", "usiget", 0, 0)
	@param.init("mxdgtsy", Fixnum, "usiset", "usiget", 0, 0)
	@param.init("lprtct", TrueClass, "uslset", "uslget", 0, 0)
	@param.init("soffxtr", Float, "usrset", "usrget", 0, 0)
	@param.init("soffxtl", Float, "usrset", "usrget", 0, 0)
	@param.init("soffxbr", Float, "usrset", "usrget", 0, 0)
	@param.init("soffxbl", Float, "usrset", "usrget", 0, 0)
	@param.init("soffxur", Float, "usrset", "usrget", 0, 0)
	@param.init("soffxul", Float, "usrset", "usrget", 0, 0)
	@param.init("soffyrt", Float, "usrset", "usrget", 0, 0)
	@param.init("soffyrb", Float, "usrset", "usrget", 0, 0)
	@param.init("soffylt", Float, "usrset", "usrget", 0, 0)
	@param.init("soffylb", Float, "usrset", "usrget", 0, 0)
	@param.init("soffyut", Float, "usrset", "usrget", 0, 0)
	@param.init("soffyub", Float, "usrset", "usrget", 0, 0)
	@param.init("xdtmax", Float, "usrset", "usrget", 0, 0)
	@param.init("xdtmin", Float, "usrset", "usrget", 0, 0)
	@param.init("ydtmax", Float, "usrset", "usrget", 0, 0)
	@param.init("ydtmin", Float, "usrset", "usrget", 0, 0)
	
	@param.init("cxttl", String, "uscset", "uscget", 0, 0)
	@param.init("cyttl", String, "uscset", "uscget", 0, 0)
	@param.init("cxfmt", String, "uscset", "uscget", 0, 0)
	@param.init("cyfmt", String, "uscset", "uscget", 0, 0)
	@param.init("cxside", String, "uscset", "uscget", 0, 0)
	@param.init("cyside", String, "uscset", "uscget", 0, 0)
	@param.init("cxspos", String, "uscset", "uscget", 0, 0)
	@param.init("cyspos", String, "uscset", "uscget", 0, 0)
	@param.init("cxunit", String, "uscset", "uscget", 0, 0)
	@param.init("cyunit", String, "uscset", "uscget", 0, 0)
	@param.init("cblkt", String, "uscset", "uscget", 0, 0)
	
      #-------- uzpack parameter ---------
	@param.init("labelxb", TrueClass, "uzlset", "uzlget", 0, 0)
	@param.init("labelxt", TrueClass, "uzlset", "uzlget", 0, 0)
	@param.init("labelxu", TrueClass, "uzlset", "uzlget", 0, 0)
	@param.init("labelyl", TrueClass, "uzlset", "uzlget", 0, 0)
	@param.init("labelyr", TrueClass, "uzlset", "uzlget", 0, 0)
	@param.init("labelyu", TrueClass, "uzlset", "uzlget", 0, 0)
	
	@param.init("rsizet0", Float, "uzrset", "uzrget", 0, 0)
	@param.init("rsizet1", Float, "uzrset", "uzrget", 0, 0)
	@param.init("rsizet2", Float, "uzrset", "uzrget", 0, 0)
	
	@param.init("rsizel0", Float, "uzrset", "uzrget", 0, 0)
	@param.init("rsizel1", Float, "uzrset", "uzrget", 0, 0)
	@param.init("rsizel2", Float, "uzrset", "uzrget", 0, 0)
	
	@param.init("rsizec0", Float, "uzrset", "uzrget", 0, 0)
	@param.init("rsizec1", Float, "uzrset", "uzrget", 0, 0)
	@param.init("rsizec2", Float, "uzrset", "uzrget", 0, 0)
	
	@param.init("uxuser", Float, "uzrset", "uzrget", 0, 0)
	@param.init("uyuser", Float, "uzrset", "uzrget", 0, 0)
	#@param.init("inclpoint", [2, Float], "inclset", "inclget", 1, 1)
	@temp_param = @param.dup
	@backup = @param.dup
      
      end
    
      private :param_init
      
      def param
	@param
      end
#------------------- method for parameters----------------------

      def set(key, val)
	@param[key]=val
      end

# by kawanabe
=begin
---Axis.set(key, val)
    p^̐ݒsB

    
    * key:p^(String)
    * val:ݒ肷lB^͊ep^QƂ̂ƁB
    gp
        Axis.set("cxttl", "xtitle")      # X̃^Cg"xtitle"ɐݒ

=end

      def get(key)
	@param[key]
      end

# by kawanabe
=begin
---Axis.get(key)
    p^QƂB

    
    * key:p^(String)
    gp
        Axis.get("cxttl")      #X̃^CgQƂB

=end

      def zfact(rfact)
	@param["rsizet1"] = @param["rsizet1"] * rfact
	@param["rsizet2"] = @param["rsizet2"] * rfact 
	@param["rsizel1"] = @param["rsizel1"] * rfact
	@param["rsizel2"] = @param["rsizel2"] * rfact
	@param["rsizec1"] = @param["rsizec1"] * rfact
	@param["rsizec2"] = @param["rsizec2"] * rfact
      end

# by DCL manual
=begin
---Axis.zfact(rfact)
    p^ 'rsize(i)', 'rsize(i)', 'rsizec(i)' (i=1,2) ׂĉ{.

    
    * rfact: {邩w肷l.(Float or Fixnum)

    l
    (1)̃\bhUZFACTĂłB

=end

      def title(cxttl, cxunit, cyttl, cyunit)
	DCL.ussttl(cxttl, cxunit, cyttl, cyunit)
      end

# by DCL manual
=begin
---Axis.title(cxttl, cxunit, cyttl, cyunit)
    Axis.drawŏW̃^Cgy Tux̒̒Pʂw肷.

    
    * cxttl: XW̃^Cg (String)
    * cxunit: XW̒P (String)
    * cyttl: YW̃^Cg (String)
    * cyunit: YW̒P (String)
    
    l
    (1)̃\bhUSSTTLĂłB
    (2)^CgtȂƂɂ, 1ȏ̃uNw肷. 

=end

      def xpttl(cside, islct, cttl, px, temp=nil)
	@param.sync
	@backup = @temp_param.set(temp, @param, @backup)
	@temp_param.sync
      
	#Fig.settrf
	
	DCL.uxpttl(cside, islct, cttl, px)
	@backup.sync
	@temp_param.clear
      end

# by DCL manual
=begin
---Axis.xpttl(cside, islct, cttl, px, temp=nil)
    ^Cg`. 

     
    * cside (String) : W`ꏊw肷 ('B','T','U')(DCL manual 3.2ߎQ).
    * islct (Fixnum) : `̑w肷 (DCL manual 3.4ߎQ).
    * cttl (String) : `^Cg.
    * px (Fixnum) : -1+1̊Ԃ̎lŃ^Cg `ʒuw肷. -1̂Ƃ悹, 0̂ƂZ^O, +1̂ƂE悹.
    * temp (Hash) : e|p^

    l
    (1)̃\bh UXPTTL ĂłB
    (2)^Cg̑̕傫̓p^ rsizec(i) ߂. 
    (3)^Cg̉̕]p̓p^ irotc(zs) ߂. 
    (4)^Cg̕`̃CCfNX̓p^ indexl(i)߂. 
    (5)p^ lbound  true  ^CgEChE̕ƃ^Cg`Ȃ; false ȂEChE̕Ă` (l false). ܂, p^ lbound  true  ^CgEChE̕ĕ`ȂƂ p^ lbmsg  true Ȃ ̎|bZ[Wo͂; false Ȃo͂Ȃ (l true). 

=end

      def ypttl(cside, islct, cttl, py, temp=nil)
	@param.sync
	@backup = @temp_param.set(temp, @param, @backup)
	@temp_param.sync
	
	#Fig.settrf
	
	DCL.uypttl(cside, islct, cttl, py)
	@backup.sync
	@temp_param.clear
      end

# by DCL manual
=begin
---Axis.ypttl(cside, islct, cttl, py, temp=nil)
    ^Cg`. 

     
    * cside (String) : W`ꏊw肷 ('L','R','U')(DCL manual 3.2ߎQ).
    * islct (Fixnum) : `̑w肷 (DCL manual 3.4ߎQ).
    * cttl (String) : `^Cg.
    * py (Fixnum) : -1+1̊Ԃ̎lŃ^Cg `ʒuw肷. -1̂Ƃ悹, 0̂ƂZ^O, +1̂ƂE悹.
    * temp (Hash) : e|p^

    l
    (1)̃\bh UYPTTL ĂłB
    (2)^Cg̑̕傫̓p^ rsizec(i) ߂. 
    (3)^Cg̉̕]p̓p^ irotc(zs) ߂. 
    (4)^Cg̕`̃CCfNX̓p^ indexl(i)߂. 
    (5)p^ lbound  true  ^CgEChE̕ƃ^Cg`Ȃ; false ȂEChE̕Ă` (l false). ܂, p^ lbound  true  ^CgEChE̕ĕ`ȂƂ p^ lbmsg  true Ȃ ̎|bZ[Wo͂; false Ȃo͂Ȃ (l true). 

=end

      def xmttl(cside, cttl, px, temp=nil)
	@param.sync
	@backup = @temp_param.set(temp, @param, @backup)
	@temp_param.sync
	
	#Fig.settrf
	
	DCL.uxmttl(cside, cttl, px)
	@backup.sync
	@temp_param.clear
      end

# by DCL manual
=begin
---Axis.xmttl(cside, cttl, px, temp=nil)
    傫߂̃^Cg`. 

    
    * cside (String) : W`ꏊw肷 ('B','T','U')(DCL manual 3.2ߎQ).
    * islct (Fixnum) : `̑w肷 (DCL manual 3.4ߎQ).
    * cttl (String) : `^Cg.
    * px (Fixnum) : -1+1̊Ԃ̎lŃ^Cg `ʒuw肷. -1̂Ƃ悹, 0̂ƂZ^O, +1̂ƂE悹.
    * temp (Hash) : e|p^

    l
    (1)̃\bh UXMTTL ĂłB
    (2)̃\bh UXPTTL (ISLCT=2)g ^Cg`Ă.

=end
 
      def ymttl(cside, cttl, py, temp=nil)
	@param.sync
	@backup = @temp_param.set(temp, @param, @backup)
	@temp_param.sync
	
	#Fig.settrf
	
	DCL.uymttl(cside, cttl, py)
	@backup.sync
	@temp_param.clear
      end

# by DCL manual
=begin
---Axis.ymttl(cside, cttl, py, temp=nil)
    傫߂̃^Cg`. 

    
    * cside (String) : W`ꏊw肷 ('L','R','U')(DCL manual 3.2ߎQ).
    * islct (Fixnum) : `̑w肷 (DCL manual 3.4ߎQ).
    * cttl (String) : `^Cg.
    * px (Fixnum) : -1+1̊Ԃ̎lŃ^Cg `ʒuw肷. -1̂Ƃ悹, 0̂ƂZ^O, +1̂ƂE悹.
    * temp (Hash) : e|p^

    l
    (1)̃\bh UYMTTL ĂłB
    (2)̃\bh UYPTTL (ISLCT=2)g ^Cg`Ă.

=end
      
      def xsttl(cside, cttl, px, temp=nil)
	@param.sync
	@backup = @temp_param.set(temp, @param, @backup)
	@temp_param.sync
	
	#Fig.settrf
	
	DCL.uxsttl(cside, cttl, px)
	@backup.sync
	@temp_param.clear
      end
 
# by DCL manual
=begin
---Axis.xsttl(cside, cttl, px, temp=nil)
    ߂̃^Cg`. 

    
    * cside (String) : W`ꏊw肷 ('B','T','U')(DCL manual 3.2ߎQ).
    * islct (Fixnum) : `̑w肷 (DCL manual 3.4ߎQ).
    * cttl (String) : `^Cg.
    * px (Fixnum) : -1+1̊Ԃ̎lŃ^Cg `ʒuw肷. -1̂Ƃ悹, 0̂ƂZ^O, +1̂ƂE悹.
    * temp (Hash) : e|p^

    l
    (1)̃\bh UXSTTL ĂłB
    (2)̃\bh UXPTTL (ISLCT=1)g ^Cg`Ă.

=end
    
      def ysttl(cside, cttl, py, temp=nil)
	@param.sync
	@backup = @temp_param.set(temp, @param, @backup)
	@temp_param.sync
	
	#Fig.settrf
	
	DCL.uysttl(cside, cttl, py)
	@backup.sync
	@temp_param.clear
      end

# by DCL manual
=begin
---Axis.ysttl(cside, cttl, py, temp=nil)
    ߂̃^Cg`. 

    
    * cside (String) : W`ꏊw肷 ('L','R','U')(DCL manual 3.2ߎQ).
    * islct (Fixnum) : `̑w肷 (DCL manual 3.4ߎQ).
    * cttl (String) : `^Cg.
    * px (Fixnum) : -1+1̊Ԃ̎lŃ^Cg `ʒuw肷. -1̂Ƃ悹, 0̂ƂZ^O, +1̂ƂE悹.
    * temp (Hash) : e|p^

    l
    (1)̃\bh UYSTTL ĂłB
    (2)̃\bh UYPTTL (ISLCT=1)g ^Cg`Ă.

=end

      def draw(x=nil, y=nil, temp=nil)
	rundef = Fig.rundef
	if(x.is_a?(Hash))
	  temp = x
	elsif((x.is_a?(NArray))&&(x.rank==2))
	  y = x.shape[1].to_f
	  x = x.shape[0].to_f
	  Basics.checkundef(x, y)
	elsif(Basics.typearray(x) && Basics.typearray(y))
	  Basics.checkundef(x, y)
	elsif(x==rundef || y==rundef)
	  Basics.checkundef(x, y)
	elsif(x==nil&&y==nil)
	  Basics.checkundef(1.0, 1.0)
	end
	@param.sync
	@backup = @temp_param.set(temp, @param, @backup)
	@temp_param.sync
	
	Fig.settrf
    
	DCL.usdaxs
	@backup.sync
	@temp_param.clear
      end

# by DCL manual
=begin
---Axis.draw(x=nil, y=nil, temp=nil)
    ftHg̍W`. ^Cgw肳Ă΃^Cg. 

    
    * x: X̍W\z (Array or NArray)
    * y: Y̍W\z (Array or NArray)
    * temp: e|p^(Hash)

    l
    (1)̃\bhUSDAXSĂłB
    (2)EBhEw肵ĂȂƂAƂx,yw肷x,yɃEBhEݒ肵A`B

=end

      def xax(cside, x=nil, y=nil, temp=nil)
	if(x.is_a?(Hash))
	  temp = x
	elsif((x.is_a?(NArray))&&(x.rank==2))
	  y = x.shape[1].to_f
	  x = x.shape[0].to_f
	  Basics.checkundef(x, y)
	elsif(Basics.typearray(x) && Basics.typearray(y))
	  Basics.checkundef(x, y)
	elsif(x==nil&&y==nil)
	  Basics.checkundef(1.0, 1.0)
	end
	@param.sync
	@backup = @temp_param.set(temp, @param, @backup)
	@temp_param.sync
	
	Fig.settrf
	
	DCL.usxaxs(cside)
	@backup.sync
	@temp_param.clear
      end

# by DCL manual
=begin
---Axis.xax(cside, x=nil, y=nil, temp=nil)
    ݐݒ肳Ă鐳Kϊɑ΂ KȖڐƃxԊuvZ, w肳ꂽꏊɍW{`.

    
    * cside: Ẅʒu ( 'B'/'T'/'U')(String)
    * x: X̍W\z (Array or NArray)
    * y: Y̍W\z (Array or NArray)
    * temp: e|p^(Hash)

    l
    (1)̃\bhUSXAXSĂłB
    (2)EBhEw肵ĂȂƂAƂx,yw肷x,yɃEBhEݒ肵A`B

=end
  
      def yax(cside, x=nil, y=nil, temp=nil)
	if(x.is_a?(Hash))
	  temp = x
	elsif((x.is_a?(NArray))&&(x.rank==2))
	  y = x.shape[1].to_f
	  x = x.shape[0].to_f
	  Basics.checkundef(x, y)
	elsif(Basics.typearray(x) && Basics.typearray(y))
	  Basics.checkundef(x, y)
	elsif(x==nil&&y==nil)
	  Basics.checkundef(1.0, 1.0)
	end
	@param.sync
	@backup = @temp_param.set(temp, @param, @backup)
	@temp_param.sync
	
	Fig.settrf
	
	DCL.usyaxs(cside)
	@backup.sync
	@temp_param.clear
      end

# by DCL manual
=begin
---Axis.yax(cside, x=nil, y=nil, temp=nil)
    ݐݒ肳Ă鐳Kϊɑ΂ KȖڐƃxԊuvZ, w肳ꂽꏊɍW{`.

    
    * cside: Ẅʒu ( 'L'/'R'/'U')(String)
    * x: X̍W\z (Array or NArray)
    * y: Y̍W\z (Array or NArray)
    * temp: e|p^(Hash)

    l
    (1)̃\bhUSYAXSĂłB
    (2)EBhEw肵ĂȂƂAƂx,yw肷x,yɃEBhEݒ肵A`B

=end
  
      module_function :param_init
      module_function :param
      module_function :zfact
      module_function :xpttl
      module_function :ypttl
      module_function :xmttl
      module_function :ymttl
      module_function :xsttl
      module_function :ysttl
      module_function :draw
      module_function :set
      module_function :get
      module_function :title
      module_function :xax
      module_function :yax
      
      param_init
      
      @param.keys.each{|i|
	eval "def #{i}; @param['#{i}']; end"
	eval "def #{i}=(val); set('#{i}', val); end"
      }
      
      @param.keys.each{|i|
	eval "module_function :#{i}"
	eval "module_function :#{i}="
      }
    end
  end
end

require "numru/advanceddcl/log"
require "numru/advanceddcl/linear"
